@@ -12,11 +12,14 @@ class AliPayException(Exception):
         self.__code = code
         self.__message = message
 
-    def __repr__(self):
-        return u"AliPayException<code:{}, message:{}>".format(self.__code, self.__message)
+    def to_unicode(self):
+        return "AliPayException: code:{}, message:{}".format(self.__code, self.__message)
 
-    def __unicode__(self):
-        return u"AliPayException<code:{}, message:{}>".format(self.__code, self.__message)
+    def __str__(self):
+        return self.to_unicode()
+
+    def __repr__(self):
+        return self.to_unicode()
 
 
 class AliPayValidationError(Exception):
